@@ -246,7 +246,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".jsonc", &["JSON with Comments"]),
         (".cr", &["Crystal"]),
         (".rq", &["SPARQL"]),
-        (".fcgi", &["Lua", "Perl", "PHP", "Ruby", "Shell", "Python"]),
+        (".fcgi", &["PHP", "Shell", "Ruby", "Perl", "Lua", "Python"]),
         (".ipf", &["IGOR Pro"]),
         (".gn", &["GN"]),
         (".vh", &["SystemVerilog"]),
@@ -301,9 +301,9 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".txl", &["TXL"]),
         (".tla", &["TLA"]),
         (".pod", &["Pod 6", "Pod"]),
-        (".cp", &["C++", "Component Pascal"]),
+        (".cp", &["Component Pascal", "C++"]),
         (".irclog", &["IRC log"]),
-        (".as", &["AngelScript", "ActionScript"]),
+        (".as", &["ActionScript", "AngelScript"]),
         (".zimpl", &["Zimpl"]),
         (".gbr", &["Gerber Image"]),
         (".ccp", &["COBOL"]),
@@ -322,7 +322,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".vcl", &["VCL"]),
         (".las", &["Lasso"]),
         (".oz", &["Oz"]),
-        (".for", &["Formatted", "Fortran", "Forth"]),
+        (".for", &["Fortran", "Forth", "Formatted"]),
         (".php5", &["PHP"]),
         (".jake", &["JavaScript"]),
         (".c++", &["C++"]),
@@ -335,7 +335,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".bib", &["BibTeX"]),
         (".mirah", &["Mirah"]),
         (".ini", &["INI"]),
-        (".ice", &["Slice", "JSON"]),
+        (".ice", &["JSON", "Slice"]),
         (".mustache", &["HTML+Django"]),
         (".wast", &["WebAssembly"]),
         (".bsv", &["Bluespec"]),
@@ -350,7 +350,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".cmake", &["CMake"]),
         (".qll", &["CodeQL"]),
         (".pogo", &["PogoScript"]),
-        (".bf", &["Brainfuck", "HyPhy"]),
+        (".bf", &["HyPhy", "Brainfuck"]),
         (".numpy", &["NumPy"]),
         (".mu", &["mupad"]),
         (".boot", &["Clojure"]),
@@ -380,7 +380,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".nlogo", &["NetLogo"]),
         (".st", &["Smalltalk", "HTML"]),
         (".1in", &["Roff", "Roff Manpage"]),
-        (".cfg", &["HAProxy", "INI"]),
+        (".cfg", &["INI", "HAProxy"]),
         (".conll", &["CoNLL-U"]),
         (".bmx", &["BlitzMax"]),
         (".lhs", &["Literate Haskell"]),
@@ -400,18 +400,18 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".nu", &["Nu"]),
         (".db2", &["SQLPL"]),
         (".flf", &["FIGlet Font"]),
-        (".dsp", &["Faust", "Microsoft Developer Studio Project"]),
+        (".dsp", &["Microsoft Developer Studio Project", "Faust"]),
         (".hc", &["HolyC"]),
         (".rest", &["reStructuredText"]),
         (".kojo", &["Scala"]),
         (".cxx-objdump", &["Cpp-ObjDump"]),
         (".xc", &["XC"]),
-        (".spec", &["RPM Spec", "Ruby", "Python"]),
+        (".spec", &["Ruby", "RPM Spec", "Python"]),
         (".gmx", &["XML"]),
         (".self", &["Self"]),
         (".slim", &["Slim"]),
         (".apl", &["APL"]),
-        (".hh", &["Hack", "C++"]),
+        (".hh", &["C++", "Hack"]),
         (".gtpl", &["Groovy"]),
         (".lsl", &["LSL"]),
         (".blade", &["Blade"]),
@@ -425,7 +425,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".tfvars", &["HCL"]),
         (".1m", &["Roff", "Roff Manpage"]),
         (".csv", &["CSV"]),
-        (".gs", &["GLSL", "Genie", "Gosu", "JavaScript"]),
+        (".gs", &["Genie", "GLSL", "JavaScript", "Gosu"]),
         (".vba", &["Vim script", "VBA"]),
         (".escript", &["Erlang"]),
         (".owl", &["Web Ontology Language"]),
@@ -433,10 +433,10 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".c-objdump", &["C-ObjDump"]),
         (".vsixmanifest", &["XML"]),
         (".xib", &["XML"]),
-        (".brd", &["Eagle", "KiCad Legacy Layout"]),
+        (".brd", &["KiCad Legacy Layout", "Eagle"]),
         (".ll", &["LLVM"]),
         (".8xp", &["TI Program"]),
-        (".fx", &["HLSL", "FLUX"]),
+        (".fx", &["FLUX", "HLSL"]),
         (".3", &["Roff", "Roff Manpage"]),
         (".tmpreferences", &["XML Property List"]),
         (".minid", &["MiniD"]),
@@ -444,7 +444,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".xojo_script", &["Xojo"]),
         (".fxh", &["HLSL"]),
         (".gypi", &["Python"]),
-        (".pm", &["X PixMap", "Perl", "Raku"]),
+        (".pm", &["Raku", "Perl", "X PixMap"]),
         (".ml4", &["OCaml"]),
         (".cake", &["C#", "CoffeeScript"]),
         (".pod6", &["Pod 6"]),
@@ -453,7 +453,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".nim.cfg", &["Nim"]),
         (".reds", &["Red"]),
         (".mxt", &["Max"]),
-        (".pp", &["Puppet", "Pascal"]),
+        (".pp", &["Pascal", "Puppet"]),
         (".pyp", &["Python"]),
         (".mysql", &["SQL"]),
         (".cmd", &["Batchfile"]),
@@ -468,7 +468,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".latte", &["Latte"]),
         (".metal", &["Metal"]),
         (".frag", &["GLSL", "JavaScript"]),
-        (".ch", &["xBase", "Charity"]),
+        (".ch", &["Charity", "xBase"]),
         (".cjs", &["JavaScript"]),
         (".glade", &["XML"]),
         (".io", &["Io"]),
@@ -522,7 +522,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".bas", &["VBA"]),
         (".cpp", &["C++"]),
         (".druby", &["Mirah"]),
-        (".mqh", &["MQL5", "MQL4"]),
+        (".mqh", &["MQL4", "MQL5"]),
         (".mkvi", &["TeX"]),
         (".qasm", &["OpenQASM"]),
         (".sparql", &["SPARQL"]),
@@ -530,7 +530,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".liquid", &["Liquid"]),
         (".hb", &["Harbour"]),
         (".aw", &["PHP"]),
-        (".shader", &["ShaderLab", "GLSL"]),
+        (".shader", &["GLSL", "ShaderLab"]),
         (".decls", &["BlitzBasic"]),
         (".dtx", &["TeX"]),
         (".cps", &["Component Pascal"]),
@@ -610,7 +610,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".bbx", &["TeX"]),
         (".ijs", &["J"]),
         (".jisonlex", &["Jison Lex"]),
-        (".l", &["Common Lisp", "PicoLisp", "Roff", "Lex"]),
+        (".l", &["Common Lisp", "Roff", "Lex", "PicoLisp"]),
         (".rbbas", &["REALbasic"]),
         (".pkgproj", &["XML"]),
         (".scss", &["SCSS"]),
@@ -621,7 +621,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".vhi", &["VHDL"]),
         (".1", &["Roff", "Roff Manpage"]),
         (".befunge", &["Befunge"]),
-        (".fr", &["Text", "Frege", "Forth"]),
+        (".fr", &["Frege", "Forth", "Text"]),
         (".ccproj", &["XML"]),
         (".zone", &["DNS Zone"]),
         (".jsb", &["JavaScript"]),
@@ -629,7 +629,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".matah", &["Stata"]),
         (".sss", &["SugarSS"]),
         (".click", &["Click"]),
-        (".mm", &["XML", "Objective-C++"]),
+        (".mm", &["Objective-C++", "XML"]),
         (".depproj", &["XML"]),
         (".pks", &["PLSQL"]),
         (".es6", &["JavaScript"]),
@@ -667,13 +667,13 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".builds", &["XML"]),
         (".hhi", &["Hack"]),
         (".asn1", &["ASN.1"]),
-        (".b", &["Brainfuck", "Limbo"]),
+        (".b", &["Limbo", "Brainfuck"]),
         (".plb", &["PLSQL"]),
         (".prefab", &["Unity3D Asset"]),
         (".8xk", &["TI Program"]),
         (".xql", &["XQuery"]),
-        (".cgi", &["Perl", "Shell", "Python"]),
-        (".odin", &["Object Data Instance Notation", "Odin"]),
+        (".cgi", &["Shell", "Perl", "Python"]),
+        (".odin", &["Odin", "Object Data Instance Notation"]),
         (".lean", &["Lean"]),
         (".osm", &["XML"]),
         (".xsp-config", &["XPages"]),
@@ -690,13 +690,13 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".xspec", &["XML"]),
         (".sublime-macro", &["JSON with Comments"]),
         (".ins", &["TeX"]),
-        (".moo", &["Mercury", "Moocode"]),
+        (".moo", &["Moocode", "Mercury"]),
         (".tfstate", &["JSON"]),
         (".mdown", &["Markdown"]),
         (".gst", &["Gosu"]),
         (".jsm", &["JavaScript"]),
         (".angelscript", &["AngelScript"]),
-        (".cls", &["ObjectScript", "TeX", "VBA", "Apex", "OpenEdge ABL"]),
+        (".cls", &["ObjectScript", "TeX", "Apex", "VBA", "OpenEdge ABL"]),
         (".workbook", &["Markdown"]),
         (".csproj", &["XML"]),
         (".tcsh", &["Tcsh"]),
@@ -738,7 +738,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".mako", &["Mako"]),
         (".pascal", &["Pascal"]),
         (".xojo_menu", &["Xojo"]),
-        (".asm", &["Assembly", "Motorola 68K Assembly"]),
+        (".asm", &["Motorola 68K Assembly", "Assembly"]),
         (".zap", &["ZAP"]),
         (".fsh", &["GLSL"]),
         (".yasnippet", &["YASnippet"]),
@@ -779,7 +779,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".lagda", &["Literate Agda"]),
         (".bash", &["Shell"]),
         (".tfstate.backup", &["JSON"]),
-        (".t", &["Perl", "Turing", "Raku", "Terra"]),
+        (".t", &["Raku", "Turing", "Terra", "Perl"]),
         (".tpb", &["PLSQL"]),
         (".ampl", &["AMPL"]),
         (".wdl", &["wdl"]),
@@ -787,7 +787,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".frm", &["VBA"]),
         (".vark", &["Gosu"]),
         (".resx", &["XML"]),
-        (".md", &["Markdown", "GCC Machine Description"]),
+        (".md", &["GCC Machine Description", "Markdown"]),
         (".arc", &["Arc"]),
         (".roff", &["Roff"]),
         (".rebol", &["Rebol"]),
@@ -822,7 +822,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".mq4", &["MQL4"]),
         (".php", &["PHP", "Hack"]),
         (".ahkl", &["AutoHotkey"]),
-        (".ms", &["Roff", "Unix Assembly", "MAXScript"]),
+        (".ms", &["MAXScript", "Roff", "Unix Assembly"]),
         (".epsi", &["PostScript"]),
         (".htm", &["HTML"]),
         (".nsh", &["NSIS"]),
@@ -876,7 +876,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".tex", &["TeX"]),
         (".erl", &["Erlang"]),
         (".glf", &["Glyph"]),
-        (".pro", &["Prolog", "Proguard", "INI", "QMake", "IDL"]),
+        (".pro", &["IDL", "Prolog", "QMake", "Proguard", "INI"]),
         (".mk", &["Makefile"]),
         (".mli", &["OCaml"]),
         (".cobol", &["COBOL"]),
@@ -888,14 +888,14 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".sed", &["sed"]),
         (".desktop", &["desktop"]),
         (".html.hl", &["HTML"]),
-        (".rs", &["RenderScript", "Rust"]),
+        (".rs", &["Rust", "RenderScript"]),
         (".scm", &["Scheme"]),
         (".pcbdoc", &["Altium Designer"]),
         (".spc", &["PLSQL"]),
         (".eex", &["HTML+EEX"]),
         (".php4", &["PHP"]),
         (".spin", &["Propeller Spin"]),
-        (".f", &["Filebench WML", "Fortran", "Forth"]),
+        (".f", &["Fortran", "Filebench WML", "Forth"]),
         (".cnc", &["G-code"]),
         (".mcmeta", &["JSON"]),
         (".smt", &["SMT"]),
@@ -921,7 +921,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".js", &["JavaScript"]),
         (".hxsl", &["Haxe"]),
         (".no", &["Text"]),
-        (".ncl", &["Text", "NCL", "XML"]),
+        (".ncl", &["NCL", "XML", "Text"]),
         (".hack", &["Hack"]),
         (".lua", &["Lua"]),
         (".reg", &["Windows Registry Entries"]),
@@ -929,7 +929,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".i7x", &["Inform 7"]),
         (".dcl", &["Clean"]),
         (".applescript", &["AppleScript"]),
-        (".d", &["D", "Makefile", "DTrace"]),
+        (".d", &["Makefile", "DTrace", "D"]),
         (".admx", &["XML"]),
         (".webapp", &["JSON"]),
         (".em", &["EmberScript"]),
@@ -963,14 +963,14 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".mdwn", &["Markdown"]),
         (".kicad_wks", &["KiCad Layout"]),
         (".jelly", &["XML"]),
-        (".prc", &["SQL", "PLSQL"]),
+        (".prc", &["PLSQL", "SQL"]),
         (".pde", &["Processing"]),
         (".vhd", &["VHDL"]),
         (".pgsql", &["PLpgSQL"]),
         (".jade", &["Pug"]),
         (".n", &["Roff", "Nemerle"]),
         (".apib", &["API Blueprint"]),
-        (".nl", &["NL", "NewLisp"]),
+        (".nl", &["NewLisp", "NL"]),
         (".hcl", &["HCL"]),
         (".adb", &["Ada"]),
         (".dpr", &["Pascal"]),
@@ -992,7 +992,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".asset", &["Unity3D Asset"]),
         (".hs-boot", &["Haskell"]),
         (".gpb", &["Gerber Image"]),
-        (".mod", &["AMPL", "XML", "Linux Kernel Module", "Modula-2"]),
+        (".mod", &["Modula-2", "Linux Kernel Module", "AMPL", "XML"]),
         (".mao", &["Mako"]),
         (".rex", &["REXX"]),
         (".jsp", &["Java Server Pages"]),
@@ -1006,7 +1006,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".ccxml", &["XML"]),
         (".plsql", &["PLSQL"]),
         (".geo", &["GLSL"]),
-        (".h", &["C", "C++", "Objective-C"]),
+        (".h", &["Objective-C", "C", "C++"]),
         (".gvy", &["Groovy"]),
         (".proj", &["XML"]),
         (".ceylon", &["Ceylon"]),
@@ -1047,7 +1047,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".snip", &["Vim Snippet"]),
         (".f77", &["Fortran"]),
         (".sthlp", &["Stata"]),
-        (".fs", &["Filterscript", "F#", "GLSL", "Forth"]),
+        (".fs", &["GLSL", "Forth", "Filterscript", "F#"]),
         (".dm", &["DM"]),
         (".rb", &["Ruby"]),
         (".duby", &["Mirah"]),
@@ -1079,7 +1079,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".4th", &["Forth"]),
         (".hx", &["Haxe"]),
         (".8", &["Roff", "Roff Manpage"]),
-        (".sls", &["Scheme", "SaltStack"]),
+        (".sls", &["SaltStack", "Scheme"]),
         (".sh.in", &["Shell"]),
         (".watchr", &["Ruby"]),
         (".edn", &["edn"]),
@@ -1103,9 +1103,9 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".cuh", &["Cuda"]),
         (".markdown", &["Markdown"]),
         (".prolog", &["Prolog"]),
-        (".g", &["GAP", "G-code"]),
+        (".g", &["G-code", "GAP"]),
         (".ring", &["Ring"]),
-        (".r", &["Rebol", "R"]),
+        (".r", &["R", "Rebol"]),
         (".rnh", &["RUNOFF"]),
         ("._coffee", &["CoffeeScript"]),
         (".vhs", &["VHDL"]),
@@ -1122,13 +1122,13 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".cljs", &["Clojure"]),
         (".mbox", &["EML"]),
         (".purs", &["PureScript"]),
-        (".ddl", &["SQL", "PLSQL"]),
+        (".ddl", &["PLSQL", "SQL"]),
         (".nut", &["Squirrel"]),
         (".csl", &["XML"]),
         (".less", &["Less"]),
         (".graphqls", &["GraphQL"]),
         (".sqf", &["SQF"]),
-        (".v", &["Verilog", "Coq", "V"]),
+        (".v", &["V", "Coq", "Verilog"]),
         (".mask", &["Unity3D Asset", "Mask"]),
         (".rexx", &["REXX"]),
         (".apacheconf", &["ApacheConf"]),
@@ -1136,7 +1136,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".blade.php", &["Blade"]),
         (".doh", &["Stata"]),
         (".ps", &["PostScript"]),
-        (".sql", &["SQLPL", "SQL", "PLpgSQL", "PLSQL", "TSQL"]),
+        (".sql", &["TSQL", "PLSQL", "SQL", "PLpgSQL", "SQLPL"]),
         (".txi", &["Texinfo"]),
         (".sma", &["Pawn"]),
         (".wisp", &["wisp"]),
@@ -1158,14 +1158,14 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".lsp", &["Common Lisp", "NewLisp"]),
         (".boo", &["Boo"]),
         (".sco", &["Csound Score"]),
-        (".inc", &["PHP", "SQL", "Assembly", "NASL", "Pawn", "Motorola 68K Assembly", "HTML", "C++", "SourcePawn", "POV-Ray SDL", "Pascal"]),
+        (".inc", &["Motorola 68K Assembly", "SourcePawn", "HTML", "PHP", "NASL", "C++", "Assembly", "SQL", "Pawn", "Pascal", "POV-Ray SDL"]),
         (".volt", &["Volt"]),
         (".yrl", &["Erlang"]),
-        (".asc", &["AGS Script", "Public Key", "AsciiDoc"]),
+        (".asc", &["AsciiDoc", "Public Key", "AGS Script"]),
         (".targets", &["XML"]),
         (".vw", &["PLSQL"]),
         (".geom", &["GLSL"]),
-        (".m", &["Mercury", "Mathematica", "MATLAB", "MUF", "Limbo", "M", "Objective-C"]),
+        (".m", &["Limbo", "M", "MUF", "Objective-C", "MATLAB", "Mathematica", "Mercury"]),
         (".yaml-tmlanguage", &["YAML"]),
         (".ahk", &["AutoHotkey"]),
         (".lslp", &["LSL"]),
@@ -1177,7 +1177,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".tab", &["SQL"]),
         (".y", &["Yacc"]),
         (".opal", &["Opal"]),
-        (".gml", &["Gerber Image", "XML", "Game Maker Language", "Graph Modeling Language"]),
+        (".gml", &["Game Maker Language", "XML", "Gerber Image", "Graph Modeling Language"]),
         (".njk", &["HTML+Django"]),
         (".yar", &["YARA"]),
         (".6pl", &["Raku"]),
@@ -1194,7 +1194,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".gp", &["Gnuplot"]),
         (".c", &["C"]),
         (".hlsl", &["HLSL"]),
-        (".sc", &["Scala", "SuperCollider"]),
+        (".sc", &["SuperCollider", "Scala"]),
         (".wxi", &["XML"]),
         (".lookml", &["LookML"]),
         (".al", &["Perl"]),
@@ -1232,7 +1232,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".gshader", &["GLSL"]),
         (".phpt", &["PHP"]),
         (".brs", &["Brightscript"]),
-        (".bb", &["BitBake", "BlitzBasic"]),
+        (".bb", &["BlitzBasic", "BitBake"]),
         (".nix", &["Nix"]),
         (".sublime-workspace", &["JSON with Comments"]),
         (".3p", &["Roff", "Roff Manpage"]),
@@ -1253,8 +1253,8 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".p", &["Gnuplot", "OpenEdge ABL"]),
         (".chem", &["Pic"]),
         (".mll", &["OCaml"]),
-        (".q", &["HiveQL", "q"]),
-        (".x", &["DirectX 3D File", "Logos", "Linker Script", "RPC"]),
+        (".q", &["q", "HiveQL"]),
+        (".x", &["Logos", "RPC", "Linker Script", "DirectX 3D File"]),
         (".cshtml", &["HTML+Razor"]),
         (".pt", &["XML"]),
         (".dats", &["ATS"]),
@@ -1272,11 +1272,11 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".rpy", &["Ren\'Py", "Python"]),
         (".r3", &["Rebol"]),
         (".jq", &["JSONiq"]),
-        (".tsx", &["XML", "TSX"]),
+        (".tsx", &["TSX", "XML"]),
         (".vstemplate", &["XML"]),
         (".plx", &["Perl"]),
         (".zcml", &["XML"]),
-        (".i", &["Assembly", "Motorola 68K Assembly", "SWIG"]),
+        (".i", &["SWIG", "Motorola 68K Assembly", "Assembly"]),
         (".gtl", &["Gerber Image"]),
         (".mly", &["OCaml"]),
         (".ronn", &["Markdown"]),
@@ -1291,7 +1291,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".haml", &["Haml"]),
         (".ly", &["LilyPond"]),
         (".abnf", &["ABNF"]),
-        (".ls", &["LiveScript", "LoomScript"]),
+        (".ls", &["LoomScript", "LiveScript"]),
         (".snippets", &["Vim Snippet"]),
         (".sbt", &["Scala"]),
         (".h++", &["C++"]),
@@ -1345,7 +1345,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".glsl", &["GLSL"]),
         (".ebuild", &["Gentoo Ebuild"]),
         (".abap", &["ABAP"]),
-        (".pl", &["Perl", "Prolog", "Raku"]),
+        (".pl", &["Raku", "Prolog", "Perl"]),
         (".arpa", &["DNS Zone"]),
         (".pmod", &["Pike"]),
         (".prw", &["xBase"]),
@@ -1379,7 +1379,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".eq", &["EQ"]),
         (".smali", &["Smali"]),
         (".vht", &["VHDL"]),
-        (".sch", &["Eagle", "XML", "KiCad Schematic", "Scheme"]),
+        (".sch", &["KiCad Schematic", "Scheme", "Eagle", "XML"]),
         (".sh", &["Shell"]),
         (".kt", &["Kotlin"]),
         (".prisma", &["Prisma"]),
